Merge
authormseledtsov
Tue, 04 Jun 2019 07:54:16 -0700
changeset 55200 9c36f33b0b01
parent 55199 3a09397c147e (current diff)
parent 55198 30fe07cac527 (diff)
child 55201 7453d5007e24
Merge
--- a/src/java.base/share/classes/java/io/ObjectOutputStream.java	Tue Jun 04 07:53:12 2019 -0700
+++ b/src/java.base/share/classes/java/io/ObjectOutputStream.java	Tue Jun 04 07:54:16 2019 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -357,8 +357,8 @@
 
     /**
      * Method used by subclasses to override the default writeObject method.
-     * This method is called by trusted subclasses of ObjectInputStream that
-     * constructed ObjectInputStream using the protected no-arg constructor.
+     * This method is called by trusted subclasses of ObjectOutputStream that
+     * constructed ObjectOutputStream using the protected no-arg constructor.
      * The subclass is expected to provide an override method with the modifier
      * "final".
      *
--- a/test/jdk/java/io/Serializable/subclass/AbstractObjectOutputStream.java	Tue Jun 04 07:53:12 2019 -0700
+++ b/test/jdk/java/io/Serializable/subclass/AbstractObjectOutputStream.java	Tue Jun 04 07:54:16 2019 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998, 2004, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1998, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -44,7 +44,7 @@
  *
  * Since serialization must override java access rules in order to
  * access private, protected and package accessible Serializable fields,
- * only trusted classes are allowed to subclass AbstractObjectInputStream.
+ * only trusted classes are allowed to subclass AbstractObjectOutputStream.
  * Subclasses of AbstractObjectOututStream must have SerializablePermission
  * "enableAbstractSubclass" or this constructor will throw a
  * SecurityException.Implementations of this class should protect themselves
--- a/src/java.base/share/classes/java/io/ObjectInputStream.java	Tue Jun 04 07:53:12 2019 -0700
+++ b/src/java.base/share/classes/java/io/ObjectInputStream.java	Tue Jun 04 07:54:16 2019 -0700
@@ -447,8 +447,8 @@
     }
 
     /**
-     * This method is called by trusted subclasses of ObjectOutputStream that
-     * constructed ObjectOutputStream using the protected no-arg constructor.
+     * This method is called by trusted subclasses of ObjectInputStream that
+     + constructed ObjectInputStream using the protected no-arg constructor.
      * The subclass is expected to provide an override method with the modifier
      * "final".
      *